@@ -23,20 +23,13 @@
 
 using namespace ContactEditor;
 
-struct LocaleAwareLessThan : std::binary_function<QString, QString, bool> {
-    bool operator()(const QString &s1, const QString &s2) const
-    {
-        return QString::localeAwareCompare(s1, s2) < 0;
-    }
-};
-
 AddressLocationWidget::AddressLocationWidget(QWidget *parent)
     : QWidget(parent)
     , mCurrentMode(CreateAddress)
 {
-    auto *topLayout = new QVBoxLayout(this);
+    auto topLayout = new QVBoxLayout(this);
 
-    auto *gridLayout = new QGridLayout;
+    auto gridLayout = new QGridLayout;
     topLayout->addLayout(gridLayout);
 
     mTypeCombo = new SelectAddressTypeComboBox(this);
@@ -44,7 +37,7 @@ AddressLocationWidget::AddressLocationWidget(QWidget *parent)
     connect(mTypeCombo, &SelectAddressTypeComboBox::textHighlighted, this, &AddressLocationWidget::slotChanged);
     gridLayout->addWidget(mTypeCombo, 0, 0, 1, 2);
 
-    QLabel *label = new QLabel(KContacts::Address::streetLabel(), this);
+    auto label = new QLabel(KContacts::Address::streetLabel(), this);
     label->setObjectName(QStringLiteral("streetlabel"));
     gridLayout->addWidget(label, 1, 0);
 
@@ -100,7 +93,7 @@ AddressLocationWidget::AddressLocationWidget(QWidget *parent)
     label->setObjectName(QStringLiteral("countrylabel"));
     gridLayout->addWidget(label, 5, 1);
     mCountryCombo = new KComboBox(this);
-    auto *edit = new KLineEdit(this);
+    auto edit = new KLineEdit(this);
     edit->setTrapReturnKey(true);
     mCountryCombo->setLineEdit(edit);
     mCountryCombo->setObjectName(QStringLiteral("countrycombobox"));
@@ -118,8 +111,8 @@ AddressLocationWidget::AddressLocationWidget(QWidget *parent)
     mButtonStack->setObjectName(QStringLiteral("buttonstacked"));
     topLayout->addWidget(mButtonStack);
 
-    QWidget *addButtonWidget = new QWidget(this);
-    auto *addButtonWidgetLayout = new QHBoxLayout(addButtonWidget);
+    auto addButtonWidget = new QWidget(this);
+    auto addButtonWidgetLayout = new QHBoxLayout(addButtonWidget);
     addButtonWidgetLayout->setContentsMargins(0, 0, 0, 0);
     mAddAddress = new QPushButton(i18n("Add Address"), this);
     mAddAddress->setObjectName(QStringLiteral("addbuttonaddress"));
@@ -128,8 +121,8 @@ AddressLocationWidget::AddressLocationWidget(QWidget *parent)
     addButtonWidgetLayout->addStretch(1);
     mButtonStack->addWidget(addButtonWidget);
 
-    QWidget *modifyButtonWidget = new QWidget(this);
-    auto *modifyButtonWidgetLayout = new QHBoxLayout(modifyButtonWidget);
+    auto modifyButtonWidget = new QWidget(this);
+    auto modifyButtonWidgetLayout = new QHBoxLayout(modifyButtonWidget);
     modifyButtonWidgetLayout->setContentsMargins(0, 0, 0, 0);
     mButtonStack->addWidget(modifyButtonWidget);
 
@@ -200,7 +193,9 @@ void AddressLocationWidget::fillCountryCombo()
         countries.append(localeStr);
     }
 
-    std::sort(countries.begin(), countries.end(), LocaleAwareLessThan());
+    std::sort(countries.begin(), countries.end(), [](const auto &s1, const auto &s2) {
+        return QString::localeAwareCompare(s1, s2) < 0;
+    });
 
     mCountryCombo->addItems(countries);
     mCountryCombo->setAutoCompletion(true);
